
# Slot: value_specification_constant


Grouping for metamodel slots that constrain the a slot value to equal a specified constant

URI: [linkml:value_specification_constant](https://w3id.org/linkml/value_specification_constant)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](String.md)

## Parents


## Children

 *  [equals_expression](equals_expression.md)
 *  [equals_number](equals_number.md)
 *  [equals_string](equals_string.md)
 *  [maximum_cardinality](maximum_cardinality.md)
 *  [minimum_cardinality](minimum_cardinality.md)
 *  [value_presence](value_presence.md)

## Used by

